Operations are functions that operate on either a list of the examples or a single example.
If the function operates on a single example, Recon will take care of applying it to all examples in a dataset.

The following operations are built into Recon

<!-- `recon.v1.filter_overlaps` -  -->
!!!error
    ... full list of operations to come

::: recon.operations
